@@ -21,9 +21,7 @@
  * Author: Carlos Garnacho <carlosg@gnome.org>
  */
 
-#ifdef HAVE_CONFIG_H
 #include "clutter-build-config.h"
-#endif
 
 #include "clutter-input-device-tool.h"
 #include "clutter-private.h"
@@ -34,12 +32,14 @@ struct _ClutterInputDeviceToolPrivate
 {
   ClutterInputDeviceToolType type;
   guint64 serial;
+  guint64 id;
 };
 
 enum {
   PROP_0,
   PROP_TYPE,
   PROP_SERIAL,
+  PROP_ID,
   PROP_LAST
 };
 
@@ -66,6 +66,9 @@ clutter_input_device_tool_set_property (GObject      *object,
     case PROP_SERIAL:
       priv->serial = g_value_get_uint64 (value);
       break;
+    case PROP_ID:
+      priv->id = g_value_get_uint64 (value);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -90,6 +93,9 @@ clutter_input_device_tool_get_property (GObject    *object,
     case PROP_SERIAL:
       g_value_set_uint64 (value, priv->serial);
       break;
+    case PROP_ID:
+      g_value_set_uint64 (value, priv->id);
+      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
     }
@@ -116,6 +122,12 @@ clutter_input_device_tool_class_init (ClutterInputDeviceToolClass *klass)
                          P_("Tool serial"),
                          0, G_MAXUINT64, 0,
                          CLUTTER_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
+  props[PROP_ID] =
+    g_param_spec_uint64 ("id",
+                         P_("Tool ID"),
+                         P_("Tool ID"),
+                         0, G_MAXUINT64, 0,
+                         CLUTTER_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
   g_object_class_install_properties (gobject_class, PROP_LAST, props);
 }
@@ -136,7 +148,7 @@ clutter_input_device_tool_init (ClutterInputDeviceTool *tool)
  *
  * Since: 1.28
  **/
-guint
+guint64
 clutter_input_device_tool_get_serial (ClutterInputDeviceTool *tool)
 {
   ClutterInputDeviceToolPrivate *priv;
@@ -170,3 +182,24 @@ clutter_input_device_tool_get_tool_type (ClutterInputDeviceTool *tool)
 
   return priv->type;
 }
+
+/**
+ * clutter_input_device_tool_get_id:
+ * @tool: a #ClutterInputDeviceTool
+ *
+ * Gets the ID of this tool, this value can be used to identify a
+ * physical tool (eg. a tablet pen) across program executions.
+ *
+ * Returns: The tool ID for this tool
+ **/
+guint64
+clutter_input_device_tool_get_id (ClutterInputDeviceTool *tool)
+{
+  ClutterInputDeviceToolPrivate *priv;
+
+  g_return_val_if_fail (CLUTTER_IS_INPUT_DEVICE_TOOL (tool), 0);
+
+  priv = clutter_input_device_tool_get_instance_private (tool);
+
+  return priv->id;
+}
