@@ -202,7 +202,7 @@ gboolean      _clutter_feature_init (GError **error);
 
 /* Diagnostic mode */
 gboolean        _clutter_diagnostic_enabled     (void);
-void            _clutter_diagnostic_message     (const char *fmt, ...);
+void            _clutter_diagnostic_message     (const char *fmt, ...) G_GNUC_PRINTF (1, 2);
 
 /* Picking code */
 guint           _clutter_pixel_to_id            (guchar        pixel[4]);
@@ -210,7 +210,6 @@ void            _clutter_id_to_color            (guint         id,
                                                  ClutterColor *col);
 
 void            _clutter_set_sync_to_vblank     (gboolean      sync_to_vblank);
-gboolean        _clutter_get_sync_to_vblank     (void);
 
 /* use this function as the accumulator if you have a signal with
  * a G_TYPE_BOOLEAN return value; this will stop the emission as
@@ -245,6 +244,10 @@ void _clutter_util_rectangle_union (const cairo_rectangle_int_t *src1,
                                     const cairo_rectangle_int_t *src2,
                                     cairo_rectangle_int_t       *dest);
 
+gboolean _clutter_util_rectangle_intersection (const cairo_rectangle_int_t *src1,
+                                               const cairo_rectangle_int_t *src2,
+                                               cairo_rectangle_int_t       *dest);
+
 
 struct _ClutterVertex4
 {
