@@ -28,15 +28,12 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "cogl-config.h"
 
 #include <string.h>
 
 #include "cogl-util.h"
 #include "cogl-color.h"
-#include "cogl-fixed.h"
 #include "cogl-color-private.h"
 #include "cogl-gtype-private.h"
 
