@@ -28,17 +28,13 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
 #include "cogl-config.h"
-#endif
 
 #include "cogl-debug.h"
 #include "cogl-context-private.h"
 #include "cogl-journal-private.h"
 #include "cogl-texture-private.h"
 #include "cogl-pipeline-private.h"
-#include "cogl-pipeline-opengl-private.h"
-#include "cogl-vertex-buffer-private.h"
 #include "cogl-framebuffer-private.h"
 #include "cogl-attribute-private.h"
 #include "cogl-private.h"
@@ -46,6 +42,8 @@
 #include "cogl-framebuffer-private.h"
 #include "cogl1-context.h"
 #include "cogl-primitives-private.h"
+#include "driver/gl/cogl-pipeline-opengl-private.h"
+#include "deprecated/cogl-vertex-buffer-private.h"
 
 #include <string.h>
 #include <math.h>
@@ -592,7 +590,7 @@ _cogl_rectangles_validate_layer_cb (CoglPipeline *pipeline,
 
           if (!warning_seen)
             g_warning ("Skipping layer %d of your pipeline consisting of "
-                       "a sliced texture (unsuported for multi texturing)",
+                       "a sliced texture (unsupported for multi texturing)",
                        state->i);
           warning_seen = TRUE;
 
