@@ -42,7 +42,7 @@
 #include <cogl/cogl-framebuffer.h>
 #include <cogl/cogl-macros.h>
 
-COGL_BEGIN_DECLS
+G_BEGIN_DECLS
 
 /**
  * cogl_get_option_group:
@@ -106,7 +106,7 @@ cogl_features_available (CoglFeatureFlags features);
  * Return value: a pointer to the requested function or %NULL if the
  *   function is not available.
  */
-CoglFuncPtr
+GCallback
 cogl_get_proc_address (const char *name);
 
 /**
@@ -857,6 +857,6 @@ COGL_DEPRECATED_FOR (CoglGLES2Context_API)
 void
 cogl_end_gl (void);
 
-COGL_END_DECLS
+G_END_DECLS
 
 #endif /* __COGL_1_CONTEXT_H__ */
