@@ -131,6 +131,12 @@ meta_backend_x11_nested_set_keymap (MetaBackend *backend,
 {
 }
 
+static gboolean
+meta_backend_x11_nested_is_lid_closed (MetaBackend *backend)
+{
+  return FALSE;
+}
+
 static gboolean
 meta_backend_x11_nested_handle_host_xevent (MetaBackendX11 *x11,
                                             XEvent         *event)
@@ -192,6 +198,7 @@ meta_backend_x11_nested_class_init (MetaBackendX11NestedClass *klass)
   backend_class->select_stage_events = meta_backend_x11_nested_select_stage_events;
   backend_class->lock_layout_group = meta_backend_x11_nested_lock_layout_group;
   backend_class->set_keymap = meta_backend_x11_nested_set_keymap;
+  backend_class->is_lid_closed = meta_backend_x11_nested_is_lid_closed;
 
   backend_x11_class->handle_host_xevent = meta_backend_x11_nested_handle_host_xevent;
   backend_x11_class->translate_device_event = meta_backend_x11_nested_translate_device_event;
