@@ -348,6 +348,7 @@ meta_surface_actor_is_argb32 (MetaSurfaceActor *self)
       return FALSE;
     default:
       g_assert_not_reached ();
+      return FALSE;
     }
 }
 
@@ -418,3 +419,44 @@ meta_surface_actor_set_transform (MetaSurfaceActor     *self,
 
   meta_shaped_texture_set_transform (priv->texture, transform);
 }
+
+void
+meta_surface_actor_set_viewport_src_rect (MetaSurfaceActor  *self,
+                                          ClutterRect       *src_rect)
+{
+  MetaSurfaceActorPrivate *priv =
+    meta_surface_actor_get_instance_private (self);
+
+  meta_shaped_texture_set_viewport_src_rect (priv->texture, src_rect);
+}
+
+void
+meta_surface_actor_reset_viewport_src_rect (MetaSurfaceActor *self)
+{
+  MetaSurfaceActorPrivate *priv =
+    meta_surface_actor_get_instance_private (self);
+
+  meta_shaped_texture_reset_viewport_src_rect (priv->texture);
+}
+
+void
+meta_surface_actor_set_viewport_dst_size (MetaSurfaceActor *self,
+                                          int               dst_width,
+                                          int               dst_height)
+{
+  MetaSurfaceActorPrivate *priv =
+    meta_surface_actor_get_instance_private (self);
+
+  meta_shaped_texture_set_viewport_dst_size (priv->texture,
+                                             dst_width,
+                                             dst_height);
+}
+
+void
+meta_surface_actor_reset_viewport_dst_size (MetaSurfaceActor *self)
+{
+  MetaSurfaceActorPrivate *priv =
+    meta_surface_actor_get_instance_private (self);
+
+  meta_shaped_texture_reset_viewport_dst_size (priv->texture);
+}
