@@ -151,6 +151,7 @@ struct _MetaWindow
   GObject parent_instance;
 
   MetaDisplay *display;
+  uint64_t id;
   guint64 stamp;
   MetaLogicalMonitor *monitor;
   MetaWorkspace *workspace;
@@ -189,7 +190,6 @@ struct _MetaWindow
   char *gtk_app_menu_object_path;
   char *gtk_menubar_object_path;
 
-  int hide_titlebar_when_maximized;
   int net_wm_pid;
 
   Window xtransient_for;
@@ -232,7 +232,7 @@ struct _MetaWindow
 
   double tile_hfraction;
 
-  int preferred_output_winsys_id;
+  uint64_t preferred_output_winsys_id;
 
   /* Whether we're shaded */
   guint shaded : 1;
