@@ -25,20 +25,22 @@
 #ifndef META_WAYLAND_BUFFER_H
 #define META_WAYLAND_BUFFER_H
 
-#include <cogl/cogl.h>
 #include <cairo.h>
 #include <wayland-server.h>
 
-#include "meta-wayland-types.h"
-#include "meta-wayland-egl-stream.h"
-#include "meta-wayland-dma-buf.h"
+#include "cogl/cogl.h"
+#include "wayland/meta-wayland-types.h"
+#include "wayland/meta-wayland-egl-stream.h"
+#include "wayland/meta-wayland-dma-buf.h"
 
 typedef enum _MetaWaylandBufferType
 {
   META_WAYLAND_BUFFER_TYPE_UNKNOWN,
   META_WAYLAND_BUFFER_TYPE_SHM,
   META_WAYLAND_BUFFER_TYPE_EGL_IMAGE,
+#ifdef HAVE_WAYLAND_EGLSTREAM
   META_WAYLAND_BUFFER_TYPE_EGL_STREAM,
+#endif
   META_WAYLAND_BUFFER_TYPE_DMA_BUF,
 } MetaWaylandBufferType;
 
@@ -54,9 +56,11 @@ struct _MetaWaylandBuffer
 
   MetaWaylandBufferType type;
 
+#ifdef HAVE_WAYLAND_EGLSTREAM
   struct {
     MetaWaylandEglStream *stream;
   } egl_stream;
+#endif
 
   struct {
     MetaWaylandDmaBufBuffer *dma_buf;
