@@ -732,7 +732,7 @@ meta_wayland_xdg_toplevel_commit (MetaWaylandSurfaceRole  *surface_role,
                                        window_geometry,
                                        pending->dx, pending->dy);
     }
-  else if (pending->dx != 0 || pending->dx != 0)
+  else if (pending->dx != 0 || pending->dy != 0)
     {
       g_warning ("XXX: Attach-initiated move without a new geometry. "
                  "This is unimplemented right now.");
@@ -1832,6 +1832,7 @@ positioner_anchor_to_placement_anchor (uint32_t anchor)
       return (META_PLACEMENT_ANCHOR_BOTTOM | META_PLACEMENT_ANCHOR_RIGHT);
     default:
       g_assert_not_reached ();
+      return META_PLACEMENT_ANCHOR_NONE;
     }
 }
 
@@ -1860,6 +1861,7 @@ positioner_gravity_to_placement_gravity (uint32_t gravity)
       return (META_PLACEMENT_GRAVITY_BOTTOM | META_PLACEMENT_GRAVITY_RIGHT);
     default:
       g_assert_not_reached ();
+      return META_PLACEMENT_GRAVITY_NONE;
     }
 }
 
